

VERSION = (1, 0, 0)
"""Application version number tuple."""

VERSION_STR = '.'.join(map(str, VERSION))
"""Application version number string."""


default_app_config = 'siteajax.apps.SiteajaxConfig'